@@ -16,3 +16,13 @@ w <- cbind(orig          = predict(fit1),
       ordered.newdata    = predict(fit2, newdata=df),
       ordered.workaround = predict(fit2, newdata=df.char))
 round(w[, -1] - w[, 1], 3)
+
+# From oscar0936330161@gmail.com Oscar Chang
+set.seed(8787)
+n <- 1000
+x1 <- factor(sample(c(0, 1), n, replace = T), ordered=TRUE)
+y  <- sample(c(1, 2, 3, 4), n, replace = T)
+w <- try(orm(y ~ x1), silent=TRUE)
+w
+x1 <- factor(sample(c(0, 1), n, replace = T))
+orm(y ~ x1)
